Reporting
------------------------------

Reports are the primary means to disseminate results of analyses outside the Equinox environment

Topbar Navigation
-------------------
Reporting functionality is accessed via the topbar menu system. This is defined as part of the core Start app. in the topbar template.



Report Types
~~~~~~~~~~~~~~~~~
There are several different types of reports:

* a specification of a set of input data
* the performance of some desired operation / calculations and finally
* where applicable, the storage of the output


Working with visual data may also lead to graphical reports. More complex reports will involve composite workflows and storage of results which may lead to specifications of risk profile assessment for an entity, optimization options etc.

Creating useful outcomes / reports is linked to specific use cases. Still under construction

Results cannot be created except through run a model workflow.

Grouped Results
~~~~~~~~~~~~~~~~

The Grouped Results List provides an overview of all available result groups. Results groups are typically (but not necessarily) created by Playbooks. In case they are the result of Playbook parametric surveys the Actions include tabular and graphical comparisons of the different results